@@ -11,6 +11,7 @@ from flask_cors import CORS
 from pymacaron_core.swagger.apipool import ApiPool
 from pymacaron_core.models import get_model
 import pymacaron.models
+from pymacaron.apiloader import load_api_models_and_endpoints
 from pymacaron.log import set_level, pymlogger
 from pymacaron.crash import set_error_reporter, generate_crash_handler_decorator
 from pymacaron.exceptions import format_error
@@ -22,6 +23,7 @@ from pymacaron.api import add_ping_hook
 log = pymlogger(__name__)
 
 
+# TODO: deprecate
 def _get_model_factory(model_name):
     # Using dynamic method creation to localize model_name
     def factory(**kwargs):
@@ -29,6 +31,62 @@ def _get_model_factory(model_name):
     return factory
 
 
+class modelpool():
+    """The modelpool of an api is a class whose attributes are all the Pymacaron
+    model classes declared in that api
+    """
+
+    def __init__(self, name):
+        self.api_name = name
+
+    def __getattr__(self, model_name):
+        raise Exception(f'Either {self.api_name}.yaml has not been loaded or it does not define object {model_name}')
+
+    def json_to_model(self, model_name, j, keep_datetime=None):
+        """Given a model name and json dict, return an instantiated pymacaron object"""
+        # TODO: keep_datetime in this method should be deprecated...
+        assert keep_datetime is not False, "Support for keep_datetime=False not implemented"
+        return getattr(self, model_name).from_json(j)
+
+
+class apipool():
+    """The apipool contains the modelpools of all loaded apis"""
+
+    @classmethod
+    def add_model(cls, api_name, model_name, model_class):
+        """Register a model class defined in an api"""
+        # Set modelpool.<model_name> to model_class. This allows writing:
+        #   from pymacaron import apipool
+        #   o = apipool.ping.Ok()
+        if not hasattr(apipool, api_name):
+            setattr(apipool, api_name, modelpool(api_name))
+        models = getattr(apipool, api_name)
+        setattr(models, model_name, model_class)
+
+    @classmethod
+    def get_model(cls, api_name):
+        """Return the pymacaron modelpool for this api"""
+        assert hasattr(apipool, api_name), f"Api {api_name} is not loaded in apipool"
+        return getattr(apipool, api_name)
+
+
+class apispecs():
+    """Keep track of the path of the openapi spec file of every loaded api"""
+
+    __api_name_to_path = {}
+
+    @classmethod
+    def register_api_path(cls, api_name, api_path):
+        """Remember where to find the openapi file of this api"""
+        apispecs.__api_name_to_path[api_name] = api_path
+
+    @classmethod
+    def get_api_path(cls, api_name):
+        """Get the path of the openapi file of this api, or None if that api has not been loaded"""
+        return apispecs.__api_name_to_path.get(api_name, None)
+
+
+
 def get_port():
     """Find which TCP port to listen to, based on environment variables"""
     if 'PORT' in os.environ:
@@ -44,6 +102,7 @@ def get_port():
     return port
 
 
+
 #
 # API: class to define then run a micro service api
 #
@@ -91,6 +150,22 @@ class API(object):
         log.info("Initialized API (%s:%s) (Flask debug:%s)" % (host, port, debug))
 
 
+    def load_default_apis(self):
+        # Load models from default builtin apis
+        for name in ['ping', 'crash']:
+            yaml_path = pkg_resources.resource_filename(__name__, 'pymacaron/%s.yaml' % name)
+            if not os.path.isfile(yaml_path):
+                yaml_path = os.path.join(os.path.dirname(sys.modules[__name__].__file__), '%s.yaml' % name)
+            load_api_models_and_endpoints(
+                api_name=name,
+                api_path=yaml_path,
+                dest_path=get_config().apis_path,
+                load_models=True,
+                load_endpoints=True,
+            )
+
+
+    # TODO: deprecate
     def _load_model_aliases(self, api):
         """Load all PyMacaronModels generated for a given api into the namespace
         of pymacaron.models so a user may write 'from pymacaron.models import <SomeModel>'
@@ -102,6 +177,7 @@ class API(object):
                 setattr(pymacaron.models, model_name, _get_model_factory(model_name))
 
 
+    # TODO: deprecate
     def load_clients(self, path=None, apis=[]):
         """Generate client libraries for the given apis, without starting an
         api server"""
@@ -138,8 +214,7 @@ class API(object):
         """Load all swagger files found at the given path, except those whose
         names are in the 'ignore' list"""
 
-        if not path:
-            raise Exception("Missing path to api swagger files")
+        path = get_config().apis_path
 
         if type(ignore) is not list:
             raise Exception("'ignore' should be a list of api names")
